=================================
``psyclone.tests.psyir.conftest``
=================================

.. automodule:: psyclone.tests.psyir.conftest

   .. contents::
      :local:

.. currentmodule:: psyclone.tests.psyir.conftest
